#
# spec file for package sendmail
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

#
# sysvinit -- build for SysVinit and not for systemd
#
%if %{undefined systemd_requires}
%global		with_sysvinit 1
%endif
%bcond_with     sysvinit
%define libmilter_somajor 1
%define libmilter_sominor 0
%define libmilter_sopatch 1
%define libmilter_soversion %{libmilter_somajor}.%{libmilter_sominor}.%{libmilter_sopatch}
%define libmilter_soname    libmilter.so.%{libmilter_somajor}.%{libmilter_sominor}

Name:           sendmail
BuildRequires:  cyrus-sasl-devel
BuildRequires:  db-devel
BuildRequires:  groff
BuildRequires:  libopenssl-devel
BuildRequires:  m4
BuildRequires:  mailx
BuildRequires:  netcfg
BuildRequires:  openldap2-devel
BuildRequires:  procmail
BuildRequires:  tcpd-devel
BuildRequires:  vacation
%if 0%{?suse_version} > 1140
BuildRequires:  libnsl-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-devel
%endif
Url:            http://www.sendmail.org/
%define         SUBDIRS libsmutil libsmdb sendmail mail.local mailstats makemap praliases rmail smrsh libmilter libsm editmap
Provides:       sendcf
Provides:       sendmail-tls
Provides:       smailcfg
Provides:       smtp_daemon
Requires:       /bin/fuser
Requires:       coreutils
Requires:       filesystem
Requires:       findutils
Requires:       m4
Requires:       make
Requires:       netcfg
Requires:       procmail
%if %{without sysvinit}
Requires(pre):  sysvinit(network)
%else
Requires(pre):  %insserv_prereq
Requires(post): %insserv_prereq
Requires(postun): %insserv_prereq
%endif
%if 0%{?suse_version} >= 1330
Requires(pre):  group(mail)
Requires(pre):  user(mail)
%endif
Requires(post): %fillup_prereq
Requires(post): coreutils
Requires(post): permissions
Requires(post): sed
Requires(posttrans): coreutils
Requires(posttrans): findutils
Requires(posttrans): m4
Requires(verify): permissions
%{?systemd_requires}
Conflicts:      smail postfix postfix-tls
Obsoletes:      sendmail-tls
Version:        8.15.2
Release:        lp150.4.27
Summary:        BSD Sendmail
License:        Sendmail
Group:          Productivity/Networking/Email/Servers
Source0:        ftp://ftp.sendmail.org/pub/sendmail/sendmail.%{version}.tar.gz
Source1:        sendmail-suse.tar.bz2
Source2:        sendmail-rpmlintrc
Source3:        sendmail-client.path
Source4:        sendmail.service
Source5:        sendmail-client.service
Source6:        sendmail.systemd
Source7:        sendmail-client.systemd
# PATCH-FIX-OPENSUSE: Add our m4 extensions and maintenance scripts
Patch0:         sendmail-8.15.2.dif
# PATCH-FIX-OPENSUSE: if select(2) is interrupted the timeout become undefined
Patch1:         sendmail-8.14.7-select.dif
# PATCH-FIX-UPSTREAM: Detect shared libraries
Patch4:         sendmail-8.14.8-m4header.patch
# PATCH-FIX-DEBIAN: systemd socket activation support for libmilter
Patch5:         sendmail-fd-passing-libmilter.patch
Patch6:         sendmail-8.15.2-openssl-1.1.0-fix.patch
Patch7:         sendmail-8.15.2-openssl-1.1.0-ecdhe-fix.patch
# PATCH-FIX-OPENSUSE: make build result reproducible
Patch8:         sendmail-8.15.2-reproducible.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%global         _sysconfdir	%{_sysconfdir}
%global         _mailcnfdir	%{_sysconfdir}/mail
%global         _localstatedir  %{_localstatedir}
%if 0%{?suse_version} < 1120
%global _libexecdir %{_exec_prefix}/lib
%endif

%description
The "Unix System Administration Handbook" calls sendmail "The most
complex and complete mail delivery system in common use..." .

Ready-made configuration files are included for systems connected by
TCP/IP (with or without a name server) and for systems using UUCP.

'procmail' is used as a local mail agent.

"sendmail" is a trademark of Sendmail, Inc.

%package devel
Summary:        BSD Sendmail Development Kit
Group:          Development/Libraries/Other
Requires:       libmilter%{libmilter_somajor}_%{libmilter_sominor}

%description devel
This package includes libraries and header files for building tools to
access sendmail features.

"sendmail" is a trademark of Sendmail, Inc.

%package -n libmilter%{libmilter_somajor}_%{libmilter_sominor}
Summary:        BSD Sendmail Content Management API (milter)
# To be exact: a MTA with libmilter support *is* required
Group:          System/Libraries
Requires:       smtp_daemon

%description -n libmilter%{libmilter_somajor}_%{libmilter_sominor}
Sendmail's Content Management API (milter) provides third-party programs to
access mail messages as they are being processed by the Mail Transfer Agent
(MTA), allowing them to examine and modify message content and
meta-information. Filtering policies implemented by Milter-conformant filters
may then be centrally configured and composed in an end-user's MTA
configuration file.

"sendmail" is a trademark of Sendmail, Inc.

%package -n libmilter-doc
Summary:        BSD Sendmail Content Management API (milter)
Group:          Documentation/HTML
Requires:       libmilter%{libmilter_somajor}_%{libmilter_sominor}
%if 0%{?suse_version} > 1140
BuildArch:      noarch
%endif

%description -n libmilter-doc
Sendmail's Content Management API (milter) provides third-party programs to
access mail messages as they are being processed by the Mail Transfer Agent
(MTA), allowing them to examine and modify message content and
meta-information. Filtering policies implemented by Milter-conformant filters
may then be centrally configured and composed in an end-user's MTA
configuration file.

"sendmail" is a trademark of Sendmail, Inc.

%package -n sendmail-starttls
Summary:        BSD Sendmail Starttls helper scripts
Group:          Productivity/Networking/Security
Requires:       cyrus-sasl-saslauthd
Requires:       openssl
%if 0%{?suse_version} > 1140
BuildArch:      noarch
%endif

%description -n sendmail-starttls
This package includes the directory layout as well as some useful
helper scripts for better SSL/TLS support.

"sendmail" is a trademark of Sendmail, Inc.

%package -n rmail
Version:        %{version}
Release:        lp150.4.27
Summary:        Rmail of the BSD Sendmail
Group:          Productivity/Networking/Email/Servers

%description -n rmail
Rmail interprets incoming mail received via uucp and passing the
processed mail on to the MTA (e.g. sendmail).

%prep
%setup -n sendmail-%{version}
%patch1 -p0 -b .select
%patch4 -p0 -b .m4head
%patch5 -p1 -b .fdmilt
if pkg-config --atleast-version=1.1.0 openssl; then
%patch6 -p1 -b .openssl11
%patch7 -p1 -b .ecdhe
fi
%patch0 -p0 -b .p0
%patch8 -p1 -b .reproducible
    tar --strip-components=1 -xf %{S:1} 
    set -f
    cat <<-EOF > file-list
	%%defattr(-,root,root)
%if %{with sysvinit}
	%%ghost %%dir %%attr(1750,root,root)   %{_localstatedir}/run/sendmail
%endif
	%%dir    %%attr(0750,root,root)        %{_localstatedir}/lib/sendmail
	%%attr(0600,root,root)                 %{_localstatedir}/lib/sendmail/statistics
	%%attr(0600,root,root)                 %{_mailcnfdir}/statistics
	%%dir    %%attr(0700,root,root)        %{_localstatedir}/spool/mqueue
	%%dir    %%attr(0700,root,root)        %{_localstatedir}/spool/mqueue/.hoststat
	# Part of filesystem RPM
	# %%dir    %%attr(0770,root,mail)      %{_localstatedir}/spool/clientmqueue
	%%attr(0660,root,mail)                 %{_localstatedir}/spool/clientmqueue/sm-client.st
	%%config %%attr(0644,root,root)        %{_sysconfdir}/permissions.d/sendmail
	%%config %%attr(0644,root,root)        %{_sysconfdir}/permissions.d/sendmail.paranoid
	EOF
    cat <<-EOF > milterversion.c
	#include "libmilter/mfapi.h"
	#include <stdio.h>
	int main()
	{
	     return printf("%d.%d.%d\n",
			   SM_LM_VRS_MAJOR(SMFI_VERSION),
			   SM_LM_VRS_MINOR(SMFI_VERSION),
			   SM_LM_VRS_PLVL(SMFI_VERSION)) > 0 ? 0 : 1;
	}
	EOF
    set +f

%build
    #
    ID=$(id -u)
    RPM_OPT_FLAGS="%{optflags} -fno-strict-aliasing -D_GNU_SOURCE"
    ARCH_LIB=%{_lib}
    export ARCH_LIB
    gcc $RPM_OPT_FLAGS -I./include -o milterversion milterversion.c
    MILTERVERSION=$(./milterversion)
    test %libmilter_soversion = $MILTERVERSION || exit 1
    sed -ri -e 's/@sm_libmilter_somajor@/%{libmilter_somajor}/' \
	    -e 's/@sm_libmilter_soname@/%{libmilter_soname}/' \
	    -e 's/@sm_libmilter_soversion@/%{libmilter_soversion}/' \
	devtools/Site/site.config.m4
    make clean
    # ingnore vacation (we have our own)
    make %{?_smp_mflags} SUBDIRS="%{SUBDIRS}"

%install
    ID=$(id -u)
    ARCH_LIB=%{_lib}
    export ARCH_LIB
    doc=%{buildroot}%{_defaultdocdir}/sendmail
    if test "$ID" -ne 0 ; then
	mkdir bin
	PATH=${PWD}/bin:$PATH
	(cat > bin/install)<<-EOF
	#!/bin/bash
	argv=""
	while test \$# -gt 0; do
	    case "\$1" in
	    -o) shift 2;;
	    -g) shift 2;;
	    *)  argv="\${argv:+"\$argv "}\$1"
		shift
	    esac
	done
	set -- \$(echo \${argv})
	exec -a install %{_bindir}/install \${1+"\$@"}
	EOF
	chmod 755 bin/install
	type -p install
    fi
    mkdir -p ${doc}
    mkdir -p ${doc}/libmilter
    mkdir -p %{buildroot}/sbin/conf.d
    mkdir -p %{buildroot}%{_bindir}
    mkdir -p %{buildroot}%{_sbindir}
    mkdir -p %{buildroot}%{_mailcnfdir}/certs
    mkdir -p %{buildroot}%{_mailcnfdir}/certs/certs
    mkdir -p %{buildroot}%{_mailcnfdir}/certs/crl
    mkdir -p %{buildroot}%{_mailcnfdir}/certs/private
    mkdir -p %{buildroot}%{_mailcnfdir}/certs/newcerts
    mkdir -p %{buildroot}%{_mailcnfdir}/certs/scripts
    mkdir -p %{buildroot}%{_mailcnfdir}/auth
%if %{with sysvinit}
    mkdir -p %{buildroot}%{_sysconfdir}/init.d
%endif
    mkdir -p %{buildroot}%{_sysconfdir}/pam.d
    mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services
    mkdir -p %{buildroot}%{_libdir}
    mkdir -p %{buildroot}%{_libexecdir}/sendmail.d/bin
    mkdir -p %{buildroot}%{_datadir}/sendmail
    mkdir -p %{buildroot}%{_includedir}/sm
    mkdir -p %{buildroot}%{_includedir}/sm/os
    chmod 0750 %{buildroot}%{_mailcnfdir}/certs
    chmod 0750 %{buildroot}%{_mailcnfdir}/auth
    mkdir -p %{buildroot}%{_sysconfdir}/permissions.d
    mkdir -p %{buildroot}%{_mandir}/man1
    mkdir -p %{buildroot}%{_mandir}/man5
    mkdir -p %{buildroot}%{_mandir}/man8
    mkdir -p %{buildroot}%{_fillupdir}
%if %{without sysvinit}
    mkdir -p %{buildroot}%{_unitdir}
    mkdir -p %{buildroot}/%{_mailcnfdir}/system
%endif
    make \
	DESTDIR=%{buildroot} \
	SUBDIRS="%{SUBDIRS}" \
	MANROOTMAN=%{_mandir}/man \
	MANROOT=%{_mandir}/cat \
	install
    # needed to be able to comple a milter which uses libsm, i.e. amavis-milter
    cd include/sm
    ln -s os/sm_os_linux.h sm_os.h
    cd ../../
    cd include/sm/os
    ln -s sm_os_linux.h sm_os.h
    cd ../../../
    cp -pr include/sm  %{buildroot}%{_includedir}/
    test "$ID" -ne 0 || \
    chown root:root    %{buildroot}%{_mailcnfdir}/submit.cf
    chmod 0644	       %{buildroot}%{_mailcnfdir}/submit.cf
    test "$ID" -ne 0 || \
    chown root:mail    %{buildroot}%{_sbindir}/sendmail
    ln -sf %{_sbindir}/sendmail %{buildroot}%{_prefix}/lib/sendmail
    mv %{buildroot}%{_sbindir}/praliases \
			      %{buildroot}%{_bindir}/praliases
    mkdir -p           %{buildroot}%{_localstatedir}/spool/mqueue/.hoststat
    test "$ID" -ne 0 || \
    chown -R root:root %{buildroot}%{_localstatedir}/spool/mqueue
    chmod 0700         %{buildroot}%{_localstatedir}/spool/mqueue
    chmod 0700         %{buildroot}%{_localstatedir}/spool/mqueue/.hoststat
%if %{with sysvinit}
    mkdir -p           %{buildroot}%{_localstatedir}/run/sendmail
    chmod 1750         %{buildroot}%{_localstatedir}/run/sendmail
%endif
    mkdir -p           %{buildroot}%{_localstatedir}/lib/sendmail
    chmod 0750         %{buildroot}%{_localstatedir}/lib/sendmail
    touch              %{buildroot}%{_localstatedir}/lib/sendmail/statistics
    test "$ID" -ne 0 || \
    chown -R root:root %{buildroot}%{_localstatedir}/lib/sendmail/statistics
    chmod 0600	       %{buildroot}%{_localstatedir}/lib/sendmail/statistics
    ln -sf %{_localstatedir}/lib/sendmail/statistics %{buildroot}%{_mailcnfdir}/statistics
    mkdir -p	       %{buildroot}%{_localstatedir}/spool/clientmqueue
    test "$ID" -ne 0 || \
    chown -R root:mail %{buildroot}%{_localstatedir}/spool/clientmqueue
    chmod 0770         %{buildroot}%{_localstatedir}/spool/clientmqueue
    touch              %{buildroot}%{_localstatedir}/spool/clientmqueue/sm-client.st
    test "$ID" -ne 0 || \
    chown -R root:mail %{buildroot}%{_localstatedir}/spool/clientmqueue/sm-client.st
    chmod 0660         %{buildroot}%{_localstatedir}/spool/clientmqueue/sm-client.st
    chmod 0755         %{buildroot}%{_libexecdir}/sendmail.d
    chmod 0755         %{buildroot}%{_libexecdir}/sendmail.d/bin
    chmod 0644         %{buildroot}%{_libdir}/*.a
    ln -sf %{_bindir}/vacation %{buildroot}%{_libexecdir}/sendmail.d/bin/
    ln -sf %{_bindir}/mail     %{buildroot}%{_libexecdir}/sendmail.d/bin/
    ln -sf %{_bindir}/procmail %{buildroot}%{_libexecdir}/sendmail.d/bin/
    install -m 0644 K* README RELE* doc/op/op.ps sendmail/SECURITY \
                       sendmail/TRACEFLAGS suse/README.SUSE \
                       contrib/{e*,re-*,sm*,passwd*}.pl \
		       contrib/etrn.0 ${doc}
    cat > ${doc}/FAQ.sendmail.html <<-'EOF'
	<html>
	<head>
	<title>Sendmail Frequently Asked Questions</title>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
	</head>
	<body>
	The latest Sendmail Frequently Asked Questions (FAQ) can be found at
	<br>
	<a href="http://www.sendmail.de/sm/open_source/support/support_faq"><b>http://www.sendmail.de/sm/open_source/support/support_faq</b></a>
	</body>
	</html>
	EOF
    GROFF_NO_SGR=1 groff -pe -me -mtty-char -Tlatin1 doc/op/op.me > ${doc}/op.txt
    install -m 0644 smrsh/README ${doc}/README.smrsh
    install -m 0644 libmilter/README ${doc}/README.libmilter
    bzip2 -9f ${doc}/*.ps
    bzip2 -9f ${doc}/*.txt
    bzip2 -9f ${doc}/RELEASE_NOTES
    tar cfC - cf . | tar xfC - %{buildroot}%{_datadir}/sendmail/
    test "$ID" -ne 0 || \
    chown root:root -R	%{buildroot}%{_datadir}/sendmail/
    chmod 0755		%{buildroot}%{_datadir}/sendmail/sh/makeinfo.sh
    rm -f  %{buildroot}%{_datadir}/sendmail/cf/Build
    rm -f  %{buildroot}%{_datadir}/sendmail/cf/README
    rm -f  %{buildroot}%{_datadir}/sendmail/cf/Makefile
    rm -f  %{buildroot}%{_datadir}/sendmail/cf/*.cf
    rm -fr %{buildroot}%{_datadir}/sendmail/*/*~ ${doc}/*~
    find %{buildroot}%{_datadir}/sendmail/ ${doc}/ %{buildroot}%{_includedir}/  "(" \
					-name '*.ldap' -o -name '*.mime' -o \
					-name '*.mrbl' -o -name '*.util' -o \
					-name '*.p0'   -o -name '*.auth2' -o \
					-name '*.dif'  -o -name '*.orig' ")" -delete
    cd suse/
    # etc/aliases and %{_sysconfdir}/aliases.d are in other packages
    #install -m 0644 aliases %{buildroot}%{_sysconfdir}/
    #install -d -m 0750 %{buildroot}%{_sysconfdir}/aliases.d
    install -m 0644 README Makefile mailertable genericstable userdb domaintable \
		    virtusertable access linux.mc linux.submit.mc \
		    linux.nullclient.mc service-nodns.switch \
		    service.switch relay-domains trusted-users \
		    local-host-names %{buildroot}%{_mailcnfdir}/
    install -m 0600 auth-info %{buildroot}%{_mailcnfdir}/auth/
    install -m 0755 sendmail.nissl %{buildroot}%{_sbindir}/
    install -m 0644 permissions %{buildroot}%{_sysconfdir}/permissions.d/sendmail
    install -m 0644 permissions.paranoid %{buildroot}%{_sysconfdir}/permissions.d/sendmail.paranoid
%if %{with sysvinit}
    install -m 0755 rc   %{buildroot}%{_sysconfdir}/init.d/sendmail
%else
    sed -ri '\@/etc/init.d/sendmail@d' %{buildroot}%{_sysconfdir}/permissions.d/sendmail
    sed -ri '\@/etc/init.d/sendmail@d' %{buildroot}%{_sysconfdir}/permissions.d/sendmail.paranoid
%endif
    install -m 0644 smtp %{buildroot}%{_sysconfdir}/pam.d/smtp
    install -m 0644 fw   %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/sendmail
    install update.sendmail %{buildroot}%{_libexecdir}/sendmail.d/update
%if 0%{?suse_version} <= 1140
    sed -ri 's/,,//g' %{buildroot}%{_libexecdir}/sendmail.d/update
%endif
    cat > %{buildroot}%{_sbindir}/config.sendmail <<-'EOF'
	#!/bin/bash
	VERBOSE=true exec %{_libexecdir}/sendmail.d/update
	EOF
    chmod 755 %{buildroot}%{_sbindir}/config.sendmail
    install -m 0644 sysconfig.sendmail      %{buildroot}%{_fillupdir}/
    install -m 0644 sysconfig.mail-sendmail %{buildroot}%{_fillupdir}/
    > ${doc}/README.sendmail-local-only
    for m in messages/sendmail-local-only.[a-z][a-z]; do
	l=${m##*.}
	n=${m##*/}
	n=${n%.*}
	cat $m >> ${doc}/README.sendmail-local-only
	echo   >> ${doc}/README.sendmail-local-only
    done
    cd ../
    if test -n "%{buildroot}" ; then
	cat %{buildroot}%{_mailcnfdir}/linux.mc		| \
	sed "s@include(\`@include(\`%{buildroot}@"	| \
	m4 | \
	sed "s@%{buildroot}@@g"	> %{buildroot}%{_sysconfdir}/sendmail.cf
	cat %{buildroot}%{_mailcnfdir}/linux.submit.mc	| \
	sed "s@include(\`@include(\`%{buildroot}@"	| \
	m4 | \
	sed "s@%{buildroot}@@g"	> %{buildroot}%{_mailcnfdir}/submit.cf
	chmod 0644 %{buildroot}%{_sysconfdir}/sendmail.cf
	chmod 0644 %{buildroot}%{_mailcnfdir}/submit.cf
    else
	m4 < %{_mailcnfdir}/linux.mc		> %{_sysconfdir}/sendmail.cf
	m4 < %{_mailcnfdir}/linux.submit.mc	> %{_mailcnfdir}/submit.cf
	chmod 0644 %{_sysconfdir}/sendmail.cf
	chmod 0644 %{_mailcnfdir}/submit.cf
    fi
%if %{with sysvinit}
    ln -sf %{_sysconfdir}/init.d/sendmail %{buildroot}%{_sbindir}/rcsendmail
%else
    ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcsendmail
    ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcsendmail-client
%endif
    ln -sf ../aliases  %{buildroot}%{_mailcnfdir}/aliases
    pushd %{buildroot}%{_mailcnfdir}/
	OPATH=$PATH
	PATH="${OPATH}:%{buildroot}%{_sbindir}:%{buildroot}%{_bindir}"
	make DESTDIR=%{buildroot} short
	PATH=$OPATH
    popd
%if %{without sysvinit}
    #
    # systemd unit conf files
    install -m 0644 %{S:3} %{buildroot}%{_unitdir}/
    install -m 0644 %{S:4} %{buildroot}%{_unitdir}/
    install -m 0644 %{S:5} %{buildroot}%{_unitdir}/
    install -m 0644 %{S:6} %{buildroot}/%{_mailcnfdir}/system/sm.pre
    install -m 0644 %{S:7} %{buildroot}/%{_mailcnfdir}/system/sm-client.pre
    chmod 0755 %{buildroot}/%{_mailcnfdir}/system/sm.pre
    chmod 0755 %{buildroot}/%{_mailcnfdir}/system/sm-client.pre
%endif
    #
    # Documentation for libmilter
    #
    install -m 0644 libmilter/docs/* ${doc}/libmilter/

    #
    # Remove some files we don't wish to package
    #
    rm -f %{buildroot}%{_sysconfdir}/aliases %{buildroot}%{_mailcnfdir}/*.db
    rm -f %{buildroot}%{_mailcnfdir}/*/*.db

%clean
rm -rf %{buildroot}

%if %{defined verify_permissions}
%verifyscript
%if %{with sysvinit}
%verify_permissions -e %{_localstatedir}/run/sendmail/
%endif
%verify_permissions -e %{_localstatedir}/spool/mqueue/
%verify_permissions -e %{_sysconfdir}/sendmail.cf
%if %{with sysvinit}
%verify_permissions -e %{_sysconfdir}/init.d/sendmail
%endif
%verify_permissions -e %{_mailcnfdir}/auth/
%verify_permissions -e %{_mailcnfdir}/certs/
%verify_permissions -e %{_libexecdir}/sendmail.d/bin/
%verify_permissions -e %{_libexecdir}/sendmail.d/bin/mail.local
%verify_permissions -e %{_libexecdir}/sendmail.d/bin/smrsh
%verify_permissions -e %{_sbindir}/sendmail
%endif

%post
# Trigger rebuild of old db's
for db in /etc/aliases.db /etc/aliases.d/*.db /etc/mail/*.db /etc/mail/*/*.db ; do
  test -e "$db"       || continue
  test -e "${db%.db}" || continue
  touch "${db%.db}"
done
# Update from newer SUSE releases or new installation
if test -f /etc/sysconfig/mail ; then
  . /etc/sysconfig/mail
fi
# Edit older configuration files
if test -s /etc/sysconfig/sendmail ; then
  sed -ri '\@^##[[:space:]]+Type:@,\@^#[[:space:]]+@ {
    \@^##[[:space:]]+Command:@b skip
    \@# enable this to change also the recipient address\.@i\
## Command:     /usr/lib/sendmail.d/update
    \@^#[[:space:]]*$@i\
## Command:     /usr/lib/sendmail.d/update
    :skip
    N
  }' /etc/sysconfig/sendmail
fi
%{fillup_only -an mail}
%if %{with sysvinit}
%{fillup_and_insserv -nY sendmail sendmail}
%else
%{fillup_only -an sendmail}
%service_add_post sendmail.service sendmail-client.service sendmail-client.path
PATH=bin:usr/bin:$PATH
if type -p systemctl > /dev/null 2>&1 ; then
  systemctl enable sendmail.service >/dev/null 2>&1 || :
  systemctl enable sendmail-client.service >/dev/null 2>&1 || :
  systemctl enable sendmail-client.path >/dev/null 2>&1 || :
fi
%endif
%if %{defined set_permissions}
%if %{with sysvinit}
%set_permissions %{_localstatedir}/run/sendmail/
%endif
%set_permissions %{_localstatedir}/spool/mqueue/
%set_permissions %{_sysconfdir}/sendmail.cf
%if %{with sysvinit}
%set_permissions %{_sysconfdir}/init.d/sendmail
%endif
%set_permissions %{_mailcnfdir}/auth/
%set_permissions %{_mailcnfdir}/certs/
%set_permissions %{_libexecdir}/sendmail.d/bin/
%set_permissions %{_libexecdir}/sendmail.d/bin/mail.local
%set_permissions %{_libexecdir}/sendmail.d/bin/smrsh
%set_permissions %{_sbindir}/sendmail
%endif

%if ! %{with sysvinit}
%pre
%service_add_pre sendmail.service sendmail-client.service sendmail-client.path
%endif

%preun
%if %{with sysvinit}
%{stop_on_removal sendmail}
%else
%service_del_preun sendmail.service sendmail-client.service sendmail-client.path
%endif

%postun
if test $1 = 0; then
%if %{with sysvinit}
    %{restart_on_update sendmail}
%endif
    rm -rf %{_localstatedir}/lib/sendmail
    exit 0
fi
%if ! %{with sysvinit}
%service_del_postun sendmail.service sendmail-client.service sendmail-client.path
%else
%{insserv_cleanup}
%endif

%posttrans
if test -x %{_libexecdir}/sendmail.d/update ; then
    VERBOSE=false %{_libexecdir}/sendmail.d/update
fi

%post -n libmilter%{libmilter_somajor}_%{libmilter_sominor} -p /sbin/ldconfig
%postun -n libmilter%{libmilter_somajor}_%{libmilter_sominor} -p /sbin/ldconfig

%files -f file-list
%defattr(-,root,root)
%dir %{_mailcnfdir}
# %{_sysconfdir}/aliases.d is part of aaa_dir
# %dir %attr(0750,root,mail) %{_sysconfdir}/aliases.d
%dir %attr(0750,root,root) %{_mailcnfdir}/auth
%dir %attr(0750,root,root) %{_mailcnfdir}/certs
%if %{without sysvinit}
%dir %attr(0750,root,root) %{_mailcnfdir}/system
%endif
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sendmail.cf
# %{_sysconfdir}/aliases is part of netcfg
# %config(noreplace) %{_sysconfdir}/aliases
%doc               %{_mailcnfdir}/README
%config(noreplace) %{_mailcnfdir}/Makefile
# this is a link
%config(noreplace) %{_mailcnfdir}/aliases
%config(noreplace) %verify(not md5 size mtime) %attr(0600,root,root) %{_mailcnfdir}/auth/auth-info
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/linux.mc
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/linux.submit.mc
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/linux.nullclient.mc
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/mailertable
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/genericstable
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/domaintable
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/virtusertable
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/access
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/userdb
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/relay-domains
%config(noreplace) %{_mailcnfdir}/service.switch
%config(noreplace) %{_mailcnfdir}/service-nodns.switch
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/trusted-users
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/local-host-names
%config(noreplace) %verify(not md5 size mtime) %{_mailcnfdir}/submit.cf
%doc %{_defaultdocdir}/sendmail
%exclude %{_defaultdocdir}/sendmail/README.libmilter
%exclude %dir %{_defaultdocdir}/sendmail/libmilter
%exclude %{_defaultdocdir}/sendmail/libmilter/*
%{_datadir}/sendmail
%{_fillupdir}/sysconfig.sendmail
%{_fillupdir}/sysconfig.mail-sendmail
%config %attr(0644,root,root) %{_sysconfdir}/pam.d/smtp
%config %attr(0644,root,root) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/sendmail
%if %{with sysvinit}
%config %attr(0744,root,root) %{_sysconfdir}/init.d/sendmail
%endif
%attr(0755,root,root) %{_libexecdir}/sendmail.d/update
%attr(0755,root,root) %{_sbindir}/config.sendmail
%if %{without sysvinit}
%config %attr(0644,root,root) %{_unitdir}/sendmail-client.path
%config %attr(0644,root,root) %{_unitdir}/sendmail.service
%config %attr(0644,root,root) %{_unitdir}/sendmail-client.service
%config %attr(0755,root,root) %{_mailcnfdir}/system/sm.pre
%config %attr(0755,root,root) %{_mailcnfdir}/system/sm-client.pre
%endif
%{_bindir}/hoststat
%{_bindir}/mailq
%{_bindir}/newaliases
%{_bindir}/praliases
%{_bindir}/purgestat
#%{_bindir}/rmail
%{_prefix}/lib/sendmail
%dir %attr(0755,root,root) %{_libexecdir}/sendmail.d/
%dir %attr(0755,root,root) %{_libexecdir}/sendmail.d/bin/
%{_libexecdir}/sendmail.d/bin/mail
%attr(0511,root,root) %{_libexecdir}/sendmail.d/bin/mail.local
%{_libexecdir}/sendmail.d/bin/procmail
%attr(0511,root,root) %{_libexecdir}/sendmail.d/bin/smrsh
%{_libexecdir}/sendmail.d/bin/vacation
%{_libexecdir}/sendmail.d/helpfile
%doc %{_mandir}/man1/mailq.1.gz
%doc %{_mandir}/man1/newaliases.1.gz
%doc %{_mandir}/man5/aliases.5.gz
%doc %{_mandir}/man8/editmap.8.gz
%doc %{_mandir}/man8/makemap.8.gz
#%doc %{_mandir}/man8/rmail.8.gz
%doc %{_mandir}/man8/sendmail.8.gz
%doc %{_mandir}/man8/smrsh.8.gz
%doc %{_mandir}/man8/mail.local.8.gz
%doc %{_mandir}/man8/mailstats.8.gz
%doc %{_mandir}/man8/praliases.8.gz
%{_sbindir}/editmap
%{_sbindir}/mailstats
%{_sbindir}/makemap
# Should we do 6555??
%attr(2555,root,mail) %{_sbindir}/sendmail
%{_sbindir}/sendmail.nissl
%{_sbindir}/rcsendmail*

%files devel
%defattr(-,root,root)
%dir %{_includedir}/libmilter
%{_includedir}/libmilter/*.h
%dir %{_includedir}/sm
%{_includedir}/sm/*.h
%dir %{_includedir}/sm/os
%{_includedir}/sm/os/*.h
%{_libdir}/libmilter.a
%{_libdir}/libmilter.so
%{_libdir}/libsmutil.a
%{_libdir}/libsm.a

%files -n libmilter%{libmilter_somajor}_%{libmilter_sominor}
%defattr(-,root,root)
%{_libdir}/libmilter.so.*
%doc %{_defaultdocdir}/sendmail/README.libmilter

%files -n libmilter-doc
%defattr(-,root,root)
%dir %doc %{_defaultdocdir}/sendmail/libmilter/
%doc %{_defaultdocdir}/sendmail/libmilter/*

%files -n sendmail-starttls
%defattr(-,root,root)
%dir %attr(0700,root,root) %{_mailcnfdir}/certs/certs/
%dir %attr(0700,root,root) %{_mailcnfdir}/certs/crl/
%dir %attr(0700,root,root) %{_mailcnfdir}/certs/private/
%dir %attr(0700,root,root) %{_mailcnfdir}/certs/newcerts/
%dir %attr(0700,root,root) %{_mailcnfdir}/certs/scripts/

%files -n rmail
%defattr(-,root,root)
%{_bindir}/rmail
%doc %{_mandir}/man8/rmail.8.gz

%changelog
* Tue Dec  5 2017 bwiedemann@suse.com
- Add sendmail-8.15.2-reproducible.patch to make package build reproducible
* Wed Nov 29 2017 werner@suse.de
- Add _FFR_TLS_EC m4 macro definition for site configuration as
  well (boo#1070065)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Nov  9 2017 werner@suse.de
- Apply former patches only if openssl 1.1.0+ are installed
* Wed Nov  8 2017 vcizek@suse.com
- support build with openssl 1.1 (bsc#1067222)
  * add patches from Fedora:
    sendmail-8.15.2-openssl-1.1.0-fix.patch
    sendmail-8.15.2-openssl-1.1.0-ecdhe-fix.patch (rh#1473971)
* Thu Aug 17 2017 kukuk@suse.de
- Add libnsl-devel build requires for glibc obsoleting libnsl
* Wed Jul 19 2017 werner@suse.de
-  Change requirements for libmilter and sendmail-devel as
  the library is also used by other MTA like postfix (boo#1049188)
* Thu May 11 2017 werner@suse.de
- Require user and group mail
* Wed Apr 12 2017 werner@suse.de
- Add bitdomain and uudomain to possible targets for refresh
* Wed Apr 12 2017 werner@suse.de
- Change spec file name scheme used for getting soname down into
  libmilter
* Tue Apr 11 2017 jengelh@inai.de
- Replace a find|xargs rm by -delete
* Thu Mar 23 2017 werner@suse.de
- New package libmilter1_0 for the shared library version of
  libmilter, the  Sendmail Content Management API
- Also new package libmilter-doc for the substantial documentation
  about Sendmail Content Management API (milter)
- Make sendmail-tls a noarch package
* Mon Mar  6 2017 werner@suse.de
- Require m4 at build time
* Mon Feb 20 2017 kukuk@suse.de
- Don't use insserv together with systemd
* Mon Sep 26 2016 werner@suse.de
- Use _unitdir macro instead asking pkg config of systemd
* Tue Jul 19 2016 dimstar@opensuse.org
- Fix License: Even https://spdx.org/licenses/Sendmail.html lists
  "Sendmail" as the valid identifier. Same as
  http://license.opensuse.org/ does. "Sendmail License" is in the
  column "Full Name". The License: tag requires the identifier.
- Fix some more rpmlint warnings:
  + sendmail: W: suse-missing-rclink sendmail:
  - Ship /usr/sbin/rcsendmail symlink to /usr/sbin/service
  + sendmail: W: suse-missing-rclink sendmail-client
  - Ship /usr/sbin/rcsendmail-client symlink to /usr/sbin/service
  + sendmail: W: suse-wrong-suse-capitalisation:
  - Rename README.SuSE to README.SUSE (fix spelling also inside
    the file).
  + sendmail: W: permissions-dir-without-slash
  - Fix permissions and permissions.paranoid inside
    sendmail-suse.tar.bz2.
  + sendmail: W: systemd-service-without-service_del_postun:
  - Add corresponding macros to postun script when not building
    with sysvinit support.
  + sendmail: W: systemd-service-without-service_add_pre:
  - Add corresponding macros to pre script when not building
    with sysvinit support.
* Thu Jun 16 2016 tchvatal@suse.com
- Drop unused patch:
  * sendmail-8.14.7-warning.patch
* Thu Jun 16 2016 tchvatal@suse.com
- Split uucp to separate package, no technical reason for it to not
  stand on its own
- Drop uucp related patches:
  + uucp-1.07-contrib.dif
  + uucp-1.07-cu.patch
  + uucp-1.07-grade.patch
  + uucp-1.07-lockdev.patch
  + uucp-1.07.dif
  + uucp-texinfo-5.0.patch
  + drop_ftime.patch
* Thu May 19 2016 werner@suse.de
- Do not use http://license.opensuse.org/ as reference for the Sendmail
  license even if stated by rpmlint but https://spdx.org/licenses/Sendmail.html
* Thu Apr 14 2016 werner@suse.de
- Avoid warning from chkstat due slash on directory path as last character
* Thu Apr 14 2016 werner@suse.de
- Update to sendmail 8.15.2 (boo#975416)
  * If FEATURE(`nopercenthack') is used then some bogus input triggered
    a recursion which was caught and logged as
    SYSERR: rewrite: excessive recursion (max 50) ...
    Fix based on patch from Ondrej Holas.
  * DHParameters now by default uses an included 2048 bit prime.
    The value 'none' previously caused a log entry claiming
    there was an error "cannot read or set DH parameters".
    Also note that this option applies to the server side only.
  * The U= mailer field didn't accept group names containing hyphens,
    underbars, or periods.  Based on patch from David Gwynne
    of the University of Queensland.
  * CONFIG: Allow connections from IPv6:0:0:0:0:0:0:0:1 to relay again.
    Patch from Lars-Johan Liman of Netnod Internet Exchange.
  * CONFIG: New option UseCompressedIPv6Addresses to select between
    compressed and uncompressed IPv6 addresses.  The default
    value depends on the compile-time option IPV6_FULL:
    For 1 the default is False, for 0 it is True, thus
    preserving the current behaviour.  Based on patch from
    John Beck of Oracle.
  * CONFIG: Account for IPv6 localhost addresses in
    FEATURE(`block_bad_helo').  Suggested by Andrey Chernov
    from FreeBSD and Robert Scheck from the Fedora Project.
  * CONFIG: Account for IPv6 localhost addresses in check_mail ruleset.
  * LIBMILTER: Deal with more invalid protocol data to avoid potential
    crashes.  Problem noted by Dimitri Kirchner.
  * LIBMILTER: Allow a milter to specify an empty macro list ("", not
    NULL) in smfi_setsymlist() so no macro is sent for the
    selected stage.
  * MAKEMAP: A change to check TrustedUser in fewer cases which was
    made in 2013 caused a potential regression when makemap
    was run as root (which should not be done anyway).
  * SECURITY: Properly set the close-on-exec flag for file descriptors
    (except stdin, stdout, and stderr) before executing mailers.
  * If header rewriting fails due to a temporary map lookup failure,
    queue the mail for later retry instead of sending it
    without rewriting the header.  Note: this is done
    while the mail is being sent and hence the transaction
    is aborted, which only works for SMTP/LMTP mailers
    hence the handling of temporary map failures is
    suppressed for other mailers. SMTP/LMTP servers may
    complain about aborted transactions when this problem
    occurs.
    See also "DNS Lookups" in sendmail/TUNING.
  * Incompatible Change: Use uncompressed IPv6 addresses by default,
    i.e., they will not contain "::".  For example,
    instead of ::1 it will be 0:0:0:0:0:0:0:1.  This
    permits a zero subnet to have a more specific match,
    such as different map entries for IPv6:0:0 vs IPv6:0.
    This change requires that configuration data
    (including maps, files, classes, custom ruleset,
    etc) must use the same format, so make certain such
    configuration data is updated before using 8.15.
    As a very simple check search for patterns like
    'IPv6:[0-9a-fA-F:]*::' and 'IPv6::'. If necessary,
    the prior format can be retained by compiling with:
    APPENDDEF(`conf_sendmail_ENVDEF', `-DIPV6_FULL=0')
    in your devtools/Site/site.config.m4 file.
  * If a connection to the MTA is dropped by the client before its
    hostname can be validated, treat it as "may be forged",
    so that the unvalidated hostname is not passed to a
    milter in xxfi_connect().
  * Add a timeout for communication with socket map servers
    which can be specified using the -d option.
  * Add a compile time option HESIOD_ALLOW_NUMERIC_LOGIN to allow
    numeric logins even if HESIOD is enabled.
  - sendmail 8.15.1
  * The new option CertFingerprintAlgorithm specifies the finger-
    print algorithm (digest) to use for the presented cert.
    If the option is not set, md5 is used and the macro
    {cert_md5} contains the cert fingerprint.
    However, if the option is set, the specified algorithm
    (e.g., sha1) is used and the macro {cert_fp} contains
    the cert fingerprint.
    That is, as long as the option is not set, the behaviour
    does not change, but otherwise, {cert_md5} is superseded
    by {cert_fp} even if you set CertFingerprintAlgorithm
    to md5.
  * The options ServerSSLOptions and ClientSSLOptions can be used
    to set SSL options for the server and client side
    respectively. See SSL_CTX_set_options(3) for a list.
    Note: this change turns on SSL_OP_NO_SSLv2 and
    SSL_OP_NO_TICKET for the client. See doc/op/op.me
    for details.
  * The option CipherList sets the list of ciphers for STARTTLS.
    See ciphers(1) for possible values.
  * Do not log "STARTTLS: internal error: tls_verify_cb: ssl == NULL"
    if a CRLFfile is in use (and LogLevel is 14 or higher.)
  * Store a more specific TLS protocol version in ${tls_version}
    instead of a generic one, e.g., TLSv1 instead of
    TLSv1/SSLv3.
  * Properly set {client_port} value on little endian machines.
    Patch from Kelsey Cummings of Sonic.net.
  * Per RFC 3848, indicate in the Received: header whether SSL or
    SMTP AUTH was negotiated by setting the protocol clause
    to ESMTPS, ESMTPA, or ESMTPSA instead of ESMTP.
  * If the 'C' flag is listed as TLSSrvOptions the requirement for the
    TLS server to have a cert is removed.  This only works
    under very specific circumstances and should only be used
    if the consequences are understood, e.g., clients
    may not work with a server using this.
  * The options ClientCertFile, ClientKeyFile, ServerCertFile, and
    ServerKeyFile can take a second file name, which must be
    separated from the first with a comma (note: do not use
    any spaces) to set up a second cert/key pair. This can
    be used to have certs of different types, e.g., RSA
    and DSA.
  * A new map type "arpa" is available to reverse an IP (IPv4 or IPv6)
    address. It returns the string for the PTR lookup, but
    without trailing {ip6,in-addr}.arpa.
  * New operation mode  'C' just checks the configuration file, e.g.,
    sendmail -C new.cf -bC
    will perform a basic syntax/consistency check of new.cf.
  * The mailer flag 'I' is deprecated and will be removed in a
    future version.
  * Allow local (not just TCP) socket connections to the server, e.g.,
    O DaemonPortOptions=Family=local, Addr=/var/mta/server.sock
    can be used.
  * If the new option MaxQueueAge is set to a value greater than zero,
    entries in the queue will be retried during a queue run
    only if the individual retry time has been reached which
    is doubled for each attempt.  The maximum retry time is
    limited by the specified value.
  * New DontBlameSendmail option GroupReadableDefaultAuthInfoFile
    to relax requirement for DefaultAuthInfo file.
  * Reset timeout after receiving a message to appropriate value if
    STARTTLS is in use.  Based on patch by Kelsey Cummings
    of Sonic.net.
  * Report correct error messages from the LDAP library for a range of
    small negative return values covering those used by OpenLDAP.
  * Fix compilation with Berkeley DB 5.0 and 6.0.  Patch from
    Allan E Johannesen of Worcester Polytechnic Institute.
  * CONFIG: FEATURE(`nopercenthack') takes one parameter: reject or
    nospecial which describes whether to disallow "%%" in the
    local part of an address.
  * DEVTOOLS: Fix regression in auto-detection of libraries when only
    shared libraries are available.  Problem reported by
    Bryan Costales.
  * LIBMILTER: Mark communication socket as close-on-exec in case
    a user's filter starts other applications.
    Based on patch from Paul Howarth.
- Modified patches
  sendmail-8.14.9.dif becomes sendmail-8.15.2.dif
  sendmail-8.14.7-select.dif
  sendmail-8.14.8-m4header.patch
  sendmail-fd-passing-libmilter.patch
  Removed patches
  sendmail-db6.diff
  sendmail-8.14.7-warning.patch
* Tue Dec  1 2015 werner@suse.de
-  Do not enforce dependencies like for amavis and saslauthd
* Mon May 26 2014 werner@suse.de
- Add patch sendmail-fd-passing-libmilter.patch from Debian sendmail
  maintainer Mikhail Gusarov to support systemd socket activation
  support also in libmilter (bnc#879790)
- Be aware that /var/run is a symbolic link to /run a tmpfs file
  system
* Fri May 23 2014 werner@suse.de
- Update to sendmail 8.14.9
  * Properly set the close-on-exec flag for file descriptors
    (except stdin, stdout, and stderr) before executing mailers.
  * Fix a misformed comment in conf.c: "/*" within comment
    which may cause a compilation error on some systems.
    Problem reported by John Beck of Oracle.
  * Fix regression in auto-detection of libraries when only
    shared libraries are available.  Problem reported by
    Bryan Costales.
- Modify patch sendmail-8.14.8.dif which is now sendmail-8.14.9.dif
* Wed Apr  2 2014 werner@suse.de
- In systemd mail-transfer-agent.target is gone even if there are
  MTAs around which will be started without socket/bus activation
* Tue Apr  1 2014 werner@suse.de
- Update to sendmail 8.14.8 (bnc#871258)
  * Properly initialize all OpenSSL algorithms for versions before
    OpenSSL 0.9.8o. Without this SHA2 algorithms may not
    work properly, causing for example failures for certs
    that use sha256WithRSAEncryption as signature algorithm.
  * When looking up hostnames, ensure only to return those records
    for the requested family (AF_INET or AF_INET6).
    On system that have NEEDSGETIPNODE and NETINET6
    this may have failed and cause delivery problems.
    Problem noted by Kees Cook.
  * A new mailer flag '!' is available to suppress an MH hack
    that drops an explicit From: header if it is the
    same as what sendmail would generate.
  * Add an FFR (for future release) to use uncompressed IPv6 addresses,
    i.e., they will not contain "::".  For example, instead
    of ::1 it will be 0:0:0:0:0:0:0:1.  This means that
    configuration data (including maps, files, classes,
    custom ruleset, etc) have to use the same format.
    This will be turned on in 8.15.  It can be enabled in 8.14
    by compiling with:
    APPENDDEF(`conf_sendmail_ENVDEF', `-D_FFR_IPV6_FULL')
    in your devtools/Site/site.config.m4 file.
  * Add an additional case for the WorkAroundBrokenAAAA check when
    dealing with broken nameservers by ignoring SERVFAIL
    errors returned on T_AAAA (IPv6) lookups at delivery time.
    Problem noted by Pavel Timofeev of OCS.
  * If available, pass LOGIN_SETCPUMASK and LOGIN_SETLOGINCLASS to
    setusercontext() on deliveries as a different user.
    Patch from Edward Tomasz Napierala from FreeBSD.
  * Add support for DHParameters 2048-bit primes.
  * CONFIG: Accept IPv6 literals when evaluating the HELO/EHLO argument
    in FEATURE(`block_bad_helo').  Suggested by Andrey Chernov.
  * LIBSMDB: Add a missing check for malloc() in libsmdb/smndbm.c.
    Patch from Bill Parker.
  * LIBSMDB: Fix minor memory leaks in libsmdb/ if allocations
    fail.  Patch from John Beck of Oracle.
  * Portability:
    On Linux use socklen_t as the type for the 3rd argument
    for getsockname/getpeername if the glibc version is at
    least 2.1.
- Add patch sendmail-8.14.8-m4header.patch from upstream
- Update patch sendmail-8.14.7.dif to sendmail-8.14.8.dif
- Modify the service files to be able to restart if a reload fails
  as well as use sync targets nss-user-lookup.target and
  nss-lookup.target. Also propagate reload from main service to
  client service and install both
* Sun Mar 23 2014 werner@suse.de
- Use _GNU_SOURCE in CFLAGS and %%_smp_mflags at make, maybe related
  to bnc#865232, that is do not reset signal handler but SA_RESTART
* Wed Dec 18 2013 werner@suse.de
- Do not use remote-fs.target but local-fs.target to make sure that
  failing remote/cifs shares let sendmail fail (bnc#855688)
* Tue Oct  8 2013 werner@suse.de
- Add config.starttls script to ask mail/imap server for certificates
* Tue Oct  1 2013 werner@suse.de
- Add saslauthd as optional requirement in the systemd service unit
- Add SENDMAIL_MTA_MODIFIER and SENDMAIL_MTA_SSL_PORT to configuration
- Split off SuSE specific file into a own tar ball
- Avoid SysVinit boot scripts on systemd based systems
* Mon Sep  9 2013 werner@suse.de
- Edit existing /etc/sysconfig/sendmail to add Command line (bnc#839033)
- Add a config.sendmail script which calls the update script verbosely
* Thu Aug  8 2013 werner@suse.de
- Use /etc/os-release instead of /etc/SuSE-release (bnc#833953)
* Mon Jul 15 2013 werner@suse.de
- New rpm had removed "prereq" flag from installation script bits
  that is that `Requires(prereq)' is not valid anymore :(((
* Sun Jun 16 2013 jengelh@inai.de
- sendmail-8.14.7.dif forces the use of SSL and SASL libraries,
  so make sure the BuildRequires are there
* Fri Jun 14 2013 jengelh@inai.de
- Add sendmail-db6.diff to fix compile abort with db >= 5
* Tue May 28 2013 fcrozat@suse.com
- Fix errors in systemd services (bnc#820858).
* Tue Apr 23 2013 werner@suse.de
- Remove FAQ.sendmail-8.14 but use a html link to upstream support
* Tue Apr 23 2013 werner@suse.de
- Update to sendmail 8.14.7
  * Drop support for IPv4-mapped IPv6 addresses to prevent the MTA
    from using a mapped address over a legitimate IPv6 address
    and to enforce the proper semantics over the IPv6
    connection.  Problem noted by Ulrich Sporlein.
  * Fix a regression introduced in 8.14.6: the wrong list of
    macros was sent to a milter in the EHLO stage.
    Problem found by Fabrice Bellet, reported via RedHat
    (Jaroslav Skarvada).
  * Fix handling of ORCPT parameter for DSNs: xtext decoding
    was not performed and a wrong syntax check was applied
    to the "addr-type" field.  Problem noted by Dan Lukes
    of Obludarium.
  * Fix handling of NUL characters in the MIME conversion functions
    so that message bodies containing them will be sent
    on properly. Note: this usually also affects mails
    that are not converted as those functions are used
    for other purposes too.  Problem noted by Elchonon
    Edelson of Lockheed Martin.
  * Do not perform "duplicate" elimination of recipients if they
    resolve to the error mailer using a temporary failure
    (4xy) via ruleset 0.  Problem noted by Akira Takahashi
    of IIJ.
  * CONTRIB: Updated version of etrn.pl script from John Beck
    of Oracle.
- Update to sendmail 8.14.6
  * Fix a regression introduced in 8.14.5: if a server offers
    two AUTH lines, the MTA would not read them after
    STARTTLS has been used and hence SMTP AUTH for
    the client side would fail.  Problem noted by Lena.
  * Do not cache hostnames internally in a non case sensitive way
    as that may cause addresses to change from lower case
    to upper case or vice versa. These header modifications
    can cause problems with milters that rely on receiving
    headers in the same way as they are being sent out such
    as a DKIM signing milter.
  * If MaxQueueChildren is set then it was possible that new queue
    runners could not be started anymore because an
    internal counter was subject to a race condition.
  * If a milter decreases the timeout it waits for a communication
    with the MTA, the MTA might experience a write() timeout.
    In some situations, the resulting error might have been
    ignored.  Problem noted by Werner Wiethege.
    Note: decreasing the communication timeout in a milter
    should not be done without considering the potential
    problems.
  * smfi_setsymlist() now properly sets the list of macros for
    the milter which invoked it, instead of a global
    list for all milters.  Problem reported by
    David Shrimpton of the University of Queensland.
  * If Timeout.resolver.retrans is set to a value larger than 20,
    then resolver.retry was temporarily set to 0 for
    gethostbyaddr() lookups. Now it is set to 1 instead.
    Patch from Peter.
  * If sendmail could not lock the statistics file due to a system
    error, and sendmail later sends a DSN for a mail that
    triggered such an error, then sendmail tried to access
    memory that was freed before (causing a crash on some
    systems).  Problem reported by Ryan Stone.
  * Do not log negative values for size= nor pri= to avoid confusing
    log parsers, instead limit the values to LONG_MAX.
  * Account for an API change in newer versions of Cyrus-SASL.
    Patch from Hajimu UMEMOTO from FreeBSD.
  * Do not try to resolve link-local addresses for IPv4 (just as it
    is done for IPv6).  Patch from John Beck of Oracle.
  * Improve logging of client and server STARTTLS connection failures
    that may be due to incompatible cipher lists by including
    the reason for the failure in a single log line.  Suggested
    by James Carey of Boeing.
- Drop sendmail-8.14.5-auth2.patch0 as this is part of 8.14.6
- Add sendmail-8.14.7-warning.patch to avoid useless gcc warning
- Refresh sendmail-8.14.7-select.dif
- Refresh sendmail-8.14.7.dif
* Fri Oct 26 2012 coolo@suse.com
- explicit buildrequire on groff, called from spec file
* Thu Oct 11 2012 coolo@suse.com
- buildrequire netcfg explicitly
* Fri Jul 13 2012 werner@suse.de
- Make if build even with older distributions
* Fri Jul 13 2012 werner@suse.de
- Use UTF-8 messages
* Fri Jul 13 2012 werner@suse.de
- Do not depend on broken umask in rpm scriptlets
* Tue Jun 19 2012 werner@suse.de
- Make SuSEconfig.sendmail a standalone update script (fate#313548)
* Fri May 25 2012 werner@suse.de
- Help to do systemctl the obvoisly (bnc#754544)
* Thu Feb  9 2012 cfarrell@suse.com
- license update: SUSE-Sendmail
  SUSE- proprietary prefix added until Sendmail is accepted as valid SPDX
  license at http://www.spdx.org/licenses
* Mon Nov 21 2011 werner@suse.de
- Allow sendmail to authenticate as client to various mail servers
  in TLS mode even if servers send 2 headers (bnc#731658)
* Thu Aug 18 2011 werner@suse.de
- Expand systemd configuration at build time
* Fri Aug 12 2011 werner@suse.de
- Use Pre exec files for configuration on the fly
* Thu Aug 11 2011 werner@suse.de
- Socket activation does not work for sendmail even with -bs
  on the command line of sendmail and StandardInput=socket
* Mon Aug  8 2011 werner@suse.de
- The approach of using makefiles requires make for sendmail
* Fri Aug  5 2011 werner@suse.de
- Make /var/run a ghost entry in spec as this is a tmpfs now and
  create it at start of sendmail if it does not exist (bnc#710279)
- First try of using systemd unit configration files for both
  sendmail MTA and sendmail MT client.  Try to start them on
  demand using systemd unit socket files for both local and remote
  network as well as systemd unit path file for local mail queue
* Tue May 31 2011 werner@suse.de
- Update to sendmail 8.14.5
  * Do not cache SMTP extensions across connections as the cache is
    based on hostname which may not be a unique identifier for a
    server, i.e., different machines may have the same hostname but
    provide different SMTP extensions.  Problem noted by Jim Hermann.
  * Avoid an out-of-bounds access in case a resolver reply for a DNS
    map lookup returns a size larger than 1K.  Based on a patch
    from Dr. Werner Fink of SuSE.
  * If a job is aborted using the interrupt signal (e.g., control-C
    from the keyboard), perform minimal cleanup to avoid invoking
    functions that are not signal-safe. Note: in previous versions
    the mail might have been queued up already and would be
    delivered subsequently, now an interrupt will always remove the
    queue files and thus prevent delivery.
  * Per RFC 6176, when operating as a TLS client, do not offer SSLv2.
  * Since TLS session resumption is never used as a client, disable
    use of RFC 4507-style session tickets.
  * Work around gcc4 versions which reverse 25 years of history and
    no longer align char buffers on the stack, breaking calls to
    resolver functions on strict alignment platforms.
    Found by Stuart Henderson of OpenBSD.
  * Read at most two AUTH lines from a server greeting (up to two
    lines are read because servers may use "AUTH mechs" and
    "AUTH=mechs"). Otherwise a malicious server may exhaust the
    memory of the client.  Bug report by Nils of MWR InfoSecurity.
  * Avoid triggering an assertion in the OpenLDAP code when the
    connection to an LDAP server is lost while making a query.
    Problem noted and patch provided by Andy Fiddaman.
  * If ConnectOnlyTo is set and sendmail is compiled with NETINET6
    it would try to use an IPv6 address if an IPv4 (or unparseable)
    address is specified.
  * If SASLv2 is used, make sure that the macro {auth_authen} is
    stored in xtext format to avoid problems with parsing it.
    Problem noted by Christophe Wolfhugel.
  * CONFIG: FEATURE(`ldap_routing') in 8.14.4 tried to add a missing
  - T<TMPF> that is required, but failed for some cases that did
    not use LDAP.  This change has been undone until a better
    solution can be implemented.  Problem found by Andy Fiddaman.
  * CONTRIB: qtool.pl: Deal with H entries that do not have a letter
    between the question marks.  Patch from Stefan Christensen.
  * DOC: Use a better description for the -i option in sendmail.
    Patch from Mitchell Berger.
- Add defines for nanaosleep and socklen_t for linux in conf.h
* Tue Dec  7 2010 coolo@novell.com
- prereq init scripts network and syslog
* Thu Sep 30 2010 rhafer@novell.com
- Removed version-specific libdb-4_5-devel from BuildRequires to be
  able to build against newer libdb Versions.
* Fri Jul 16 2010 werner@suse.de
- Newer killproc sends only SIGTERM as required by LSB if -TERM is
  specified on the command line.  Use the default which is SIGTERM
  followed by SIGKILL if the timeout of 5 seconds is reached.
* Fri Feb  5 2010 werner@suse.de
- Use upstream patch for bnc#559517
* Wed Jan 27 2010 werner@suse.de
- Update to bug fix release sendmail 8.14.4
  * Handle bogus certificates containing NUL characters
    in CNs by placing a string indicating a bad certificate
    in the {cn_subject} or {cn_issuer} macro.  Patch inspired
    by Matthias Andree's changes for fetchmail.
  * During the generation of a queue identifier an integer overflow
    could occur which might result in bogus characters
    being used.  Based on patch from John Vannoy of
    Pepperdine University.
  * Prevent a crash when a hostname lookup returns a seemingly
    valid result which contains a NULL pointer (this seems
    to be happening on some Linux versions).
  * Fix overflow of an internal array when parsing some replies
    from a milter.  Problem found by Scott Rotondo
  * Fix handling of `b' modifier for DaemonPortOptions on little
    endian machines for loopback address.  Patch from
    John Beck of Sun Microsystems.
  * Fix a potential memory leak in libsmdb/smdb1.c found by parfait.
    Based on patch from Jonathan Gray of OpenBSD.
  * Fix memory leak that occurred when smfi_setsymlist()
    was used.  Based on patch by Dan Lukes.
- Add patch to avoid overflow of buffer for DNS resolver (bnc#559517)
* Tue Nov 11 2008 ro@suse.de
- drop klogd prereq (prereq cycle)
* Mon Nov 10 2008 ro@suse.de
- drop sysconfig prereq
* Tue Sep 30 2008 werner@suse.de
- Use -fPIC for libraries (bnc#428289)
* Sun Aug 24 2008 ro@suse.de
- fix fillup_and_insserv options
* Wed Aug  6 2008 varkoly@suse.de
- (bnc#414960) sendmail doesn't have any "Name: " tag in firewall definition
* Wed Jul 30 2008 werner@suse.de
- Make boot script know about new upcoming startpar and insserv
* Wed Jul 16 2008 werner@suse.de
- Make poll25 more fail safe
* Thu Jun 19 2008 werner@suse.de
- Make /bin/fuser required (bnc#401477)
* Tue May  6 2008 werner@suse.de
- Update to bug fix release sendmail 8.14.3:
  * the MTA accessed storage after it free()d it. This was a
    regression introduced in 8.14.2.
  * ruleset processing: the function cataddr() could cause the
    addition of the BlankSub character between some tokens when
    it should not happen and thus failures in rule matching.
  * the libmilter state engine did not deal correctly with
    milters that requested the omission of protocol steps during
    the negotiation callback.
* Fri Feb 22 2008 werner@suse.de
- Make the name `smtp' of the smtp port to a real m4 string
* Wed Feb 20 2008 werner@suse.de
- Clean up spec file
- Add support for an other MTA port, be sure the client can connect
  to the new port of the MTA
* Mon Feb 18 2008 werner@suse.de
- Don't forget port even if sendmail listen only local (bnc#362642)
* Fri Dec 14 2007 werner@suse.de
- Update to release sendmail 8.14.1
  * fix an important bug in the milter function smfi_chgfrom()
    which could cause the loss of a message body.
  * fix the handling of queued messages with 8 bit characters in
    From: or To: header which could be "mistaken" for internal
    control characters during a queue run and trigger various
    consistency checks.
  * fix the handling of lines longer than MAXLINE-1 characters in
    certain cases.
* Fri Jul 20 2007 coolo@suse.de
- don't build require openldap2. all we need is a client
* Tue Jun 19 2007 werner@suse.de
- sendmail rc script provides smtp
* Thu May 10 2007 werner@suse.de
- Replace old RBL's with new RBL's (bug #272246)
* Tue Apr 24 2007 werner@suse.de
- Add smtp configuration for pam (bug #247352)
- Add sendmail configuration for SuSEfirewall (bug #247352)
* Mon Apr 16 2007 werner@suse.de
- Update the boot script dependcies (bug #262215)
* Thu Apr  5 2007 werner@suse.de
- Update to release sendmail 8.14.1
- Add port check for polling smtp port (fate #302078)
* Fri Feb 16 2007 werner@suse.de
- Branch new package rmail from sendmail source
- Split off uucp spec file from this spec file
* Mon Feb 12 2007 werner@suse.de
- Make it build nonroot
* Thu Feb  1 2007 werner@suse.de
- Add socket mapping for usage of Cyrus IMAP server (#241060)
* Fri Jan 19 2007 werner@suse.de
- update uucp configuration
* Thu Aug 10 2006 werner@suse.de
- Update to bug fix release sendmail 8.13.8
- Remove update messages
* Thu Jun 22 2006 werner@suse.de
- Do not touch db files if makemap fails
* Tue Jun 20 2006 werner@suse.de
- Update to sendmail version 8.13.7
- Add some more comments to the dnsbl feature due no longer
  available free providers of DNS based rejection list.
- Move the `accept unresolvable/unqualified domains/senders' from
  the expensive.m4 feature toward to the nodns.m4 hack.
- Add a comment that the nodns.m4 hack should be used in
  conjunction with a smart host
* Mon Jun 19 2006 werner@suse.de
- The symlink /etc/mail/aliases is config(noreplace) (bug #185589)
* Tue May 30 2006 werner@suse.de
- Proper update of the fix for VU#146718 (bug #173998)
* Wed May 24 2006 schwab@suse.de
- Don't strip binaries.
* Wed May 10 2006 werner@suse.de
- VU#146718: Fix sendmail denial of service with MIME (bug #173998)
* Thu Mar 23 2006 werner@suse.de
- Touch data source file instead of removeing data base (#160285)
* Wed Mar 22 2006 werner@suse.de
- Use official sendmail 8.3.16 instead of the patched version for
  the security issue CERT VU834865 (#156417)
* Mon Mar 20 2006 werner@suse.de
- Get CERT VU834865 patch working on s390x
- Avoid invalid timeval's if select() catch EINTR
* Thu Mar  9 2006 werner@suse.de
- Fix race condition in signal handling CERT VU834865 (#156417)
* Tue Feb  7 2006 werner@suse.de
- Increase polling time for active port 25 to 10 seconds (#148563)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 11 2005 werner@suse.de
- Do not use localhost as remote host with fuser
* Fri Nov 11 2005 werner@suse.de
- Move /var/run/sendmail/statistics to /var/lib/sendmail/
* Thu Oct 13 2005 werner@suse.de
- Update sendmail to version 8.13.5
- Update sendmail faq
* Fri Sep 30 2005 werner@suse.de
- I do not rewrite ldpa interface of sendmail with not documented
  ldap function calls, therefore set LDAP_DEPRECATED
* Tue Jun 28 2005 werner@suse.de
- Make UUCP massage size an sysconfig option
* Mon Jun 20 2005 werner@suse.de
- Add some clearing words to the comment for what is accepted for
  relaying with sendmail.
* Mon Jun 20 2005 kukuk@suse.de
- Use -fPIE instead of -fpie
* Fri Jun 17 2005 werner@suse.de
- Use -fpie/-pie
* Sun May  1 2005 werner@suse.de
- Wait on port 25 of localhost to be sure that sendmail has
  open this port before we start the queue runner.
* Wed Mar 30 2005 ro@suse.de
- fix version number for devel subpackage
* Wed Mar 30 2005 werner@suse.de
- Update to sendmail version 8.13.4
- Update sendmail faq
* Sun Feb 27 2005 ro@suse.de
- package /usr/bin/cu as 755
* Wed Feb 23 2005 werner@suse.de
- Add permissions file sendmail.paranoid to be able to disable MTA
* Wed Jan 26 2005 werner@suse.de
- Update to sendmail 8.13.3
- Add official close_wait patch
* Sat Jan 15 2005 schwab@suse.de
- Use <owner>:<group> in permissions file.
* Thu Dec 16 2004 werner@suse.de
- Update to sendmail 8.13.2
- Make it work
* Tue Dec 14 2004 werner@suse.de
- Fix problem with two different session of one sendmail binary by
  using new ignore feature of start/killproc (bug #48790)
* Thu Nov 11 2004 ro@suse.de
- adapt permssions in filelist to permissions in permissions file
* Wed Sep 15 2004 werner@suse.de
- Better description of the sendmail options for both master daemon
  and client runner, shorten client sleeping time (bug #45309)
* Tue Aug 31 2004 werner@suse.de
- Do only local port message and only in case of an update
  from a system without this feature.
* Tue Aug 31 2004 werner@suse.de
- Move forward to new update messages scheme
* Mon Aug 30 2004 ro@suse.de
- temporary solution: comment out all update mails
* Mon Aug  2 2004 werner@suse.de
- Update to sendmail 8.13.1
- Make access_db feature an option to avoud trouble with the
  default of the new  and automatic enabled greet_pause feature
* Fri Jul 30 2004 werner@suse.de
- Remove /var/spool/clientmqueue from file list because this one
  is provided by RPM filesystem for the uid/gid mail.
- Update FAQ.sendmail-8.12 to newest version.
* Thu Jul 29 2004 werner@suse.de
- Add switch for masquerade_entire_domain and domaintable
  feature to SuSEconfig of sendmail.
- Add missed statistics file for sendmail client (bug #40584)
* Fri Apr  2 2004 werner@suse.de
- Add linux.submit.mc and generate the shipped submit.cf out of
  them. This should avoid missing SuSEconfig runs or customers
  which do not move the submit.cf.SuSEconfig over the submit.cf.
  (bugs #37952, #32348).
* Thu Mar 18 2004 werner@suse.de
- SusEconfig.sendmail: return exit status of failed commands
  (bug #36492)
* Fri Feb 13 2004 werner@suse.de
- Fix amavis package name (bug #34544)
* Wed Dec 17 2003 werner@suse.de
- Fix typos (bug #32344, #32345)
- Changes within SMTP AUTH
  * Add comment about rpm to be installed
    cyrus-sasl-(gssapi|otp|digestmd5|crammd5|plain)
  * Add an all option for all AUTH mechanisms
  * Make TLS and SASL work together
- Test for dialup hosts
  * Add confTRY_NULL_MX_LIST for MSP
  * Add generics domain feature for MSP
* Mon Oct  6 2003 werner@suse.de
- Remove backshlash in linux.mc (bug #32037)
* Thu Sep 18 2003 werner@suse.de
- Update to 8.12.10 due security fixes
* Wed Sep 17 2003 werner@suse.de
- Security fix for sendmail (prescan2)
* Wed Sep  3 2003 werner@suse.de
- Add try-restart option for update (bug #29044)
* Thu Aug 28 2003 mmj@suse.de
- Add sysconfig metadata [#28899]
* Thu Aug 28 2003 mmj@suse.de
- Sendmail requires m4, which is no longer default [#29454]
* Mon Jul 28 2003 werner@suse.de
- Fix amavis(d) typo
* Mon Jul 28 2003 werner@suse.de
- Fix chown usage
* Tue Jul 22 2003 werner@suse.de
- Fix bug #27117: use asci file as reference for mode of db
- Move from amavis(d) to amavis-new
* Mon Jun 30 2003 werner@suse.de
- Add manual pages again
* Thu Jun 26 2003 kukuk@suse.de
- Don't create .dif files
* Fri Jun 13 2003 kukuk@suse.de
- Fix spec file to build again
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Apr 15 2003 werner@suse.de
- Update to 8.12.9 (including the last two security patches)
- Update FAQ
- Add SENDMAIL_ALLMASQUERADE for servers using yp, DNS (etc/aliases,
  /etc/hosts)
- Add /etc/mail/local-host-names for masquerade and generic domain
* Tue Apr  1 2003 draht@suse.de
- sendmail.8.12-prescan.patch fixes another overflow security problem.
* Wed Feb 26 2003 werner@suse.de
- Security fix to avoid remote root access
* Wed Feb 12 2003 werner@suse.de
- The same procedure? The same procedure as every spec: Use
  preun not post for removing info entry
* Tue Feb 11 2003 werner@suse.de
- Fix bug #22765: better description in auth-info
* Tue Feb 11 2003 werner@suse.de
- Expand Amavis check
* Wed Jan 15 2003 werner@suse.de
- Remove backup file of patch before installation
* Wed Jan 15 2003 werner@suse.de
- Be sure that library directory exist on all architecture
* Tue Jan 14 2003 werner@suse.de
- Update to senbdmail 8.12.7
- Re-enable IPv6 support
- Make GLIBC_VERSION macro work (sigh!)
- Use BuildRoot
- Use meta tags for sysconfig files (bug #22687)
* Tue Jan 14 2003 werner@suse.de
- Add some more comments about smtp auth, correct replacement
  off encoded passphrase
- Switch to SASL2
* Fri Nov 29 2002 werner@suse.de
- SMRSH should check the called program
- Fix bug #20475: now we've three sendmail processes:
  one master, one client for controlling the clientmqueue
  and its child for handling clientmqueue.
* Mon Sep  9 2002 werner@suse.de
- sendmail depends on yp information (bug #18913)
* Mon Sep  2 2002 werner@suse.de
- Switch to bugfix release 8.12.6
* Tue Aug 27 2002 werner@suse.de
- Be paranoid: -fno-strict-aliasing on all platforms (bug #17432)
* Mon Aug 26 2002 werner@suse.de
- Make amavis optional due its only available on i386 (bug #18337)
- Rename require `ntp' to `$time' (bug #18337)
* Mon Aug 26 2002 werner@suse.de
- Move NULLCLIENT from /etc/sysconfig/mail to
  /etc/sysconfig/sendmail  because  sendmail and postfix use this
  on different.
- Add a line to the comment for NULLCLIENT to get correct values.
  (bug #18301)
* Fri Aug 16 2002 werner@suse.de
- Add PreReq (bug #17990)
* Wed Aug 14 2002 werner@suse.de
- Don't be fooled by "no" for variable values (bug #17749)
* Mon Aug  5 2002 werner@suse.de
- Temporary fix for s390 to get makemap working
* Thu Jul 18 2002 werner@suse.de
- Make nullclient work
* Tue Jul 16 2002 werner@suse.de
- Add some more comments for localhost and masquerade (bug #16952)
- Add DNS RBL support to SuSEconfig.sendmail (bug #16951)
- Make last change work
* Mon Jul 15 2002 kukuk@suse.de
- Remove /etc/aliases from filelist
* Thu Jul 11 2002 werner@suse.de
- Try to use db4
* Thu Jul 11 2002 werner@suse.de
- Enable trusted user file in both MSP and MTA (bug #16930)
- Use confTRUSTED_USERS in MSP
- Add changes from Volker Kuhlmann <kuhlmav@elec.canterbury.ac.nz>
  for supporting black lists with SuSEconfig
* Tue Jul  9 2002 werner@suse.de
- Add /etc/aliases.d/ and a scanner in SuSeconfig.sendmail to
  get files therein into /etc/sendmail.cf. Add check in
  /etc/mail/Makefile ... (bug #15921)
* Tue Jul  9 2002 werner@suse.de
- Add sanity check for NULLCLIENT redirect (bug #16871)
- Add user vscan to trusted user list (bug #16496)
- Update to sendmail 8.12.5
* Thu Jul  4 2002 ro@suse.de
- fix compilation with openldap-2.1
* Tue Apr 30 2002 werner@suse.de
- Fix path of cyrus deliver program (bug# 16056)
- Add m4 option for both sendmail.cf and submit.cf  (bug# 15409)
* Wed Apr 24 2002 werner@suse.de
- Update ot bugfix release 8.12.3
- Correction of the SMTP AUTH db generation
* Tue Apr  9 2002 werner@suse.de
- Oops: move autoconf change log entry to uucp change log
* Thu Mar 28 2002 werner@suse.de
- Add Obsoltes for sendmail-tls (bug #15579)
* Wed Mar 13 2002 werner@suse.de
- Avoid header rewrite for sendmail client (fix bug #14910)
* Tue Mar  5 2002 werner@suse.de
- Force insserv call (fix bug #14359)
* Fri Mar  1 2002 werner@suse.de
- As requested: Add mailman and mailman-owner to aliases
* Fri Mar  1 2002 pthomas@suse.de
- Fix small typo in mail sent after installation.
* Wed Feb 27 2002 werner@suse.de
- Be sure that we catch all rc.config variables
- Be sure that the new required sendmail options will be included
  in SENDMAIL_ARGS
* Tue Feb 26 2002 werner@suse.de
- More work for SMTPD_LISTEN_REMOTE: if the old system has
  SMTP=yes in /etc/rc.config we remember this decision at
  pre install time and change the default for SMTPD_LISTEN_REMOTE
  from "no" to "yes" at post install time.
* Tue Feb 26 2002 werner@suse.de
- Fix bug #13905: With 8.12 we need to add our domain used in
  FROM_HEADER in the class G (generic domains)
* Mon Feb 25 2002 werner@suse.de
- Export %%_lib to site.config.m4 to make it work on ia64.
* Mon Feb 25 2002 werner@suse.de
- fix bug #13830: catch EINTR on select.
* Thu Feb 21 2002 werner@suse.de
- Add SMTPD_LISTEN_REMOTE to be able to switch off remote
  mail connections.
* Wed Feb 20 2002 werner@suse.de
- Fix bug #13188 and #13521: Avoid mail loss by running both
  sendmail master and client.
- Add and correct comments
- Install sendmail/SECURITY
- Fix bug #12462 by new configure option SENDMAIL_LUSER to map
  local mail with unknown local recipients.
* Thu Feb 14 2002 werner@suse.de
- Correct comment about full qualified hostname which is located
  in /etc/HOSTNAME now.
* Wed Feb 13 2002 werner@suse.de
- Run two daemons: one for sendmail server acts and one for the
  new client msp acts to deserve mails to port 25
- Insserv by default, because the server daemons must listen on
  port 25 for the msp sendmail client used by  MTA's.
- Create /etc/mal/submit.cf to get nocanonify, nodns, and
  masquerade into /etc/mal/submit.cf
* Sun Feb 10 2002 ro@suse.de
- new option for bz2 tar is "j"
* Tue Feb  5 2002 ro@suse.de
- rename old rc.config variable names on update
* Wed Jan 30 2002 werner@suse.de
- Remove YAST_ASK (#12972)
* Mon Jan 28 2002 werner@suse.de
- sysconfig.mail changes
- remove rc.config from README's
* Wed Jan 23 2002 werner@suse.de
- Minor changes like including new features into linux.mc
  and using the official MILTER macro of 8.12.2.
* Mon Jan 21 2002 werner@suse.de
- Package split into sendmail and sendmail-devel
- Notify if user has /etc/mail/sendmail.ct or /etc/mail/sendmail.cw
- Correct LICENSE in PDB
* Sun Jan 20 2002 link@suse.de
- for compiling a milter client, we need /usr/lib/libsm.a and
  /usr/include/sm
* Fri Jan 18 2002 werner@suse.de
- Use clientmqueue interface, that means there is a user and
  group mail together with group writable directory for group
  mail and sendmail is sgid mail.
- Implement STARTTLS and SASL interface for client and server side
- Move /etc/mail/default-auth-info to /etc/mail/auth/auth-info(.db)
  and use the FEATURE(authinfo) not DefaultAuthInfo
- Use /etc/mail/certs/ for STARTTLS data
- Install editmap
- Use FEATURE(delay_checks) in dialup.m4
- Use `.' at the end of MAIL_HUP, LOCAL_RELAY, and SMART_HOST if
  a FQDN is used.
- Fix bug #10601: Use content of /etc/HOSTNAME if FQDN
* Thu Jan 17 2002 werner@suse.de
- Update to 8.12.2
  Use official MILTER now
  Use SM_CONF_SHM, EGD for STARTTLS, and DNSMAP
- Move from sendmail.ct and sendmail.cw to local-host-names
  and local-host-names
- Enable STARTTLS, and SASL by default
- Make NULLCLIENT and SMTP-AUTH a configure option
- Remove rc.config from any comment
- DOMAIN macro should be called before MAILER macro
- Use /etc/sysconfig/mail and /etc/sysconfig/amavis
- Make it compile
* Tue Jan 15 2002 egmont@suselinux.hu
- removed colons from startup/shutdown messages
* Fri Dec 14 2001 ro@suse.de
- moved rc.config.d -> sysconfig, removed SMTP variable
* Thu Nov 22 2001 werner@suse.de
- Do not escape backquote within linux.mc (#12429)
* Thu Aug 30 2001 werner@suse.de
- More on bug #9097
* Wed Aug 22 2001 werner@suse.de
- Security update to 8.11.6 (bugtraq id 3163)
* Tue Aug 14 2001 werner@suse.de
- Update to 8.11.5
- Fix bug #9097
* Wed Jun 27 2001 werner@suse.de
- More re-ordering of cpp directives
* Wed Jun 27 2001 werner@suse.de
- Re-order cpp directive to be not included within printf
* Wed Jun  6 2001 werner@suse.de
- Simple fix in sendmail.nissl script
- Add hops fix
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Thu Apr 26 2001 werner@suse.de
- Add missed entries in /etc/mail/linux.mc
* Thu Apr  5 2001 werner@suse.de
- Add alias for amavis
* Wed Apr  4 2001 werner@suse.de
- Add message about libwrap and sendmail if host.allow is used
* Thu Mar 29 2001 werner@suse.de
- Add interface for amavis
- Move mfapi.h to /usr/include/libmilter/
* Wed Mar 21 2001 werner@suse.de
- Update to sendmail 8.11.3
- Add libmilter.a and co
* Thu Mar 15 2001 ro@suse.de
- changed for openldap2
* Thu Mar 15 2001 ro@suse.de
- fixed neededforbuild for openldap
* Fri Feb 23 2001 werner@suse.de
- Check for YAST_ASK value for all variables used be SuSEconfig
* Wed Jan 17 2001 werner@suse.de
- Change init.d location in sendmails permission file
* Tue Jan  9 2001 ro@suse.de
- re-added sfio compile fix from Andreas Schwab
* Tue Jan  9 2001 werner@suse.de
- Update to 8.11.2 due BUG fixes
  * Sendmail, Inc. and the Sendmail Consortium are proud to
    announce the release of sendmail 8.11.2. This is a maintenance
    release which contains bug fixes for problems found after
    8.11.1 was released.
* Mon Dec 18 2000 werner@suse.de
- Add touch of *.db file to set mtime of those files
* Mon Dec 11 2000 werner@suse.de
- Add LSB header to init script
* Wed Dec  6 2000 bk@suse.de
- add /usr/lib/sendmail.d/bin (like /usr/lib/sendmail.d) to %%files
* Tue Nov 28 2000 kukuk@suse.de
- Move init script to /etc/init.d
* Fri Nov 24 2000 werner@suse.de
- Update to 8.11.1
- Add a Makefile for /etc/mail/
- Minor changes within suse-linux.m4
* Mon Nov  6 2000 ro@suse.de
- fixed neededforbuild
* Wed Sep 27 2000 werner@suse.de
- Fix VERSIONID format handling
* Mon Sep 11 2000 werner@suse.de
- Fix some typos in README.SuSE (Thanks to Pavel Janik)
* Tue Sep  5 2000 werner@suse.de
- correct FAQ name
* Mon Sep  4 2000 werner@suse.de
- Update to 8.11.0
  * Hopefully reverse lookup works even with IPv6
  * Adapted the patches of 8.10.2
- Add MASQUERADE_DOMAINS for masquerade of disjoint namespaces
- Move /var/run/sendmail.control to /var/run/sendmail/control
* Tue Jul 25 2000 werner@suse.de
- Add missed helpfile to file list.
- Correct two typo's
* Fri Jul 14 2000 werner@suse.de
- Use FQHOSTNAME in /etc/rc.config or /etc/HOSTNAME before calling
  hostname because the hostname maybe configured but not active.
* Tue Jul 11 2000 werner@suse.de
- Set Timeout.ident to `0s' for SuSE Linux because many sites do
  not run identd or have disabled auth/ident protocol
* Tue Jun 20 2000 werner@suse.de
- Remove FROM_HEADER from /etc/rc.config.d/sendmail.rc.config
  (bug #2881)
* Mon Jun 19 2000 werner@suse.de
- Security update to 8.10.2
* Wed May 10 2000 werner@suse.de
- Add a README.SuSE at /usr/share/doc/packages/sendmail/
- Make sendmail accept sticky but group writable directories
- Correct order of mailers in SuSEconfig script
* Tue May  9 2000 werner@suse.de
- Add loud comment to hopefully weak up otherwise not thinking
  system adiminstrators.
- Use dummy domains only within linux.mc.
* Fri Apr 14 2000 werner@suse.de
- New version 8.10.1 (some security fixes)
* Fri Apr 14 2000 werner@suse.de
- Add tcpd into neededforbuild
* Thu Apr  6 2000 werner@suse.de
- Update to version 8.10.0 of sendmail
  * convert SuSE patches if not already in there
  * change our extensions to the new version (e.g. bsmtp, fido)
  * add mail500 mailer for (open)ldap
  * local mailer shouldn't use MX records
  * a few fixes withion the M4 macro tools
  * fix configure script
  * make libc5/nis+ changes dynamically
  * add example /etc/mail/relay-domains
  * add some informations on various files in /etc/mail/
  * move /etc/smrsh/ to /usr/lib/sendmail.d/bin/
  * install helpfile into /usr/lib/sendmail.d/
  * do NOT build and install vacation, we have our own
* Tue Feb 29 2000 schwab@suse.de
- Fix inconsistent printf format/arguments.
* Mon Feb 28 2000 werner@suse.de
- Add patch which avoid alignment problems
* Mon Feb 21 2000 ke@suse.de
- add Copyright tag to the uucp subpackage
- beautify Group tags
* Mon Feb 14 2000 ro@suse.de
- move man to /usr/share using macro
* Fri Feb 11 2000 werner@suse.de
- Fix m4 source path during installation
* Mon Jan 10 2000 werner@suse.de
- Correct stupid ` ' bug ;^)
* Thu Dec 23 1999 werner@suse.de
- Move DOMAIN(generic) from suse-linux.m4 to linux.mc and
  SuSEconfig.sendmail
- Add /etc/mail/README.linux to the rpm binary file.
* Tue Dec 14 1999 ro@suse.de
- create directory /var/lib/uucp (no longer in aaa_dir)
* Thu Dec  2 1999 werner@suse.de
- Make it ready for 5.3 (libc5)
* Mon Nov  8 1999 werner@suse.de
- Fix some permissions
* Fri Nov  5 1999 schwab@suse.de
- Fix typo in %%post
* Wed Nov  3 1999 werner@suse.de
- Workaround for fillup kludge
* Wed Nov  3 1999 werner@suse.de
- really disable tcpwrapper
* Tue Nov  2 1999 werner@suse.de
- Adapted the db1 patch to the last change
* Mon Nov  1 1999 werner@suse.de
- Currently disabled: libwrap from tcpd (feature for next SuSE)
- Don't use passwd in service switches because currently not used
  by sendmail
* Fri Oct 29 1999 werner@suse.de
- Remove doubled alias `abuse'
* Thu Oct 28 1999 werner@suse.de
- Add some more comments
- Split nocanonify and nodns to support configurations found
  with an update.
- Still unresolved: Usage of TCPWRAPPER
* Wed Oct 27 1999 werner@suse.de
- Add linebreak in warning
* Wed Oct 27 1999 werner@suse.de
- Add description for SENDMAIL_GENERICS_DOMAIN
* Wed Oct 27 1999 werner@suse.de
- Fix some minor bugs:
  * source /etc/rc.config.d/sendmail.rc.config if available
  * Expand AliasFile for ldap
  * Locate AliasFile at /etc/aliases
  * Add some more comments about nis, nisplus in service.switch
  * Make FEATURE ldap usable
* Tue Oct 26 1999 werner@suse.de
- Add some patches
  * ldap.893.patch (some fixes for ldap support)
  * mime.c.patch.893 (avoid buffer overflow die mime mails)
  * mrbl.p3.893 (enable multiple realtime blackhole list)
  * util.c.893.patch (avoid freeing of pointer in signal handler)
- Add own changes
  * a new feature/ldap.m4 for (open)ldap support
  * a new feature/expensive.m4 (expensive smtp)
  * a new feature/dialup.m4 (defer delivery mode)
  * a new hack/nodns.m4 (combine nocanonify and service-nodns.switch)
  * add service-nodns.switch and service.switch (passwd with nis)
    in /etc/mail/
  * add a new ostype/suse-linux.m4 with our default configuration
  * change /etc/mail/linux.mc, /etc/mail/linux.nullclient.mc,
    and /sbin/conf.d/SuSEconfig to fit new suse-linux.m4
  * add some anti-spam possibilities in /etc/mail/linux.mc
  * make IP_SRCROUTE work for newer kernels and glibc
  * make USESETEUID and HASSETREUID work for the
    appropiate kernel and glibc version.
  * add IP adresses 127.x.x.x for relaying in /etc/mail/access
  * change permissions for /var/spool/mqueue
  * use `.hoststat' directory
  * use DOMAIN(generic)
  * add some default aliases (abuse and spam)
  * use wrapper library (/etc/hosts.allow and /etc/hosts.deny)
  * enable nisplus support
  * enable ldap support
  * add text version of intro, op, and usenix
* Mon Sep 20 1999 ro@suse.de
- added provides smtp_daemon
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Sep 10 1999 uli@suse.de
- fixed manpath in Linux.ppc
* Thu Aug  5 1999 uli@suse.de
- updated FAQ
* Thu Jul 22 1999 bs@suse.de
- switched back to prior version, because /etc/mail/linux.mc is mentioned
  in our manual.
* Tue Jul 20 1999 florian@suse.de
- better configuration and anti spam option
- delete FAQ from distribution
- sample config files only in /usr/doc
* Mon Jul 12 1999 ro@suse.de
- do not pre-format man-pages
* Thu Jun 10 1999 ro@suse.de
- fixed build for libc5
* Tue May 18 1999 ro@suse.de
- updated db1-patch
* Fri May 14 1999 choeger@suse.de
- add on for SuSEconfig.sendmail for DoD Sites
  FEATURE(\`accept_unresolvable_domains')dnl
  FEATURE(\`accept_unqualified_senders')dnl
  will be set if SENDMAIL_EXPENSIVE=yes
* Tue Apr  6 1999 choeger@suse.de
- removed feature nodns, because it's declared as no-op
* Sun Apr  4 1999 choeger@suse.de
- new package sendmail-8.9.3
- new feature /etc/mail/access
* Wed Feb 17 1999 ro@suse.de
- removed rmail and rmail.8 (moved to package uucp)
- build uucp from same specfile
* Mon Jan 11 1999 ro@suse.de
- Makefile.Linux: objdir changed to Linux.2.* (respect alpha)
* Mon Dec 14 1998 bs@suse.de
- created notify message
- fixed comment in rc.config
* Thu Dec 10 1998 florian@suse.de
- update check.tar.gz to the newest version
- use /var/spool/mqueue instead of /var/mqueue
- add statistics prog sendmail.nissl
- mv smrsh prog dir to /etc/smrsh
- add userdb
- etc/aliases: add more logic and fix some paths
- add /tmp-race-fixes to expn.pl
- mv /etc/mail/sendmail.st /var/log/
- fix some paths in sendmail docu
- add LUSER_RELAY example to /etc/mail/linux.mc
- add bug-fixes if someone recompiles with TCPWRAPPERS defined
- add SENDMAIL_GENERICS_DOMAIN to rc.config
- change most files in /etc/mail to config(noreplace)
- dynamic linking against -lresolv -lnsl
- do not compile with XDEBUG
* Mon Dec  7 1998 ro@suse.de
- updated init-script
- build for libc5 as well as for glibc
* Sat Dec  5 1998 bs@suse.de
- mark /etc/sendmail.cf and /etc/aliases as "noreplace".
- mark mailertable, virtusertable, genericstable as "noreplace".
- skipped notice mail for sys admin.
- don't include *.db
- SuSEconfig.sendmail: fixed problem, if *.db do not exist.
* Thu Nov  5 1998 ro@suse.de
- use -ldb (db1 exists only for glibc-2.1)
* Tue Sep 29 1998 ro@suse.de
- BETA ONLY: use /usr/include/db1 and -ldb1
  use -lresolv and -lnsl
* Wed Mar  4 1998 florian@suse.de
- add newer anti-spam rules
- comment out majordomo-entries in /etc/aliases
- do not use "smtp:" for nullclient file
* Mon Mar  2 1998 florian@suse.de
- marked /etc/mail/aliases as %%config
* Mon Feb  9 1998 florian@suse.de
- newer /etc/mail/README
- newer anti-spam rules
- make all database files optional in linux.mc
- do not use the "-f" option for the database files
- use the new SuSE-functions to check with md5sums if a new sendmail.cf
  should be written
* Fri Jan 16 1998 bs@suse.de
- minor bugfix in /sbin/conf.d/SuSEconfig.sendmail
  (exit if no rc.config exists)
* Thu Nov 27 1997 florian@suse.de
- fix some typos in docu files
- update to newest version of Anti-Spam support
* Wed Nov 19 1997 florian@suse.de
- enable NIS support
* Sun Nov 16 1997 florian@suse.de
- update /etc/mail/README
* Mon Oct 27 1997 florian@suse.de
- update to sendmail 8.8.8
- first start for a docu file in /etc/mail/README
- new parameters in rc.config (/var/adm/fillup-templates/rc.config.sendmail)
- per default additional database files in /etc/mail are used
- /sbin/conf.d/SuSEconfig.sendmail gernerates /etc/sendmail.cf
- add support for anti-spam macros from Claus Aßmann
- sample /etc/mail/linux.mc for complex email setups
* Sun Apr 27 1997 bs@suse.de
  start sendmail in background in sbin/init.d/sendmail
* Thu Feb 27 1997 bs@suse.de
  added alias faxmaster
* Wed Jan 22 1997 florian@suse.de
- add uucp and mdom to the list of trusted users
- update to version 8.8.5
- add slightly better /etc/aliases
* Thu Jan  2 1997 florian@suse.de
- update to 8.8.4 (due to a security hole)
* Thu Jan  2 1997 florian@suse.de
- update to 8.8.3 (due to a big security hole)
* Thu Jan  2 1997 florian@suse.de
- Update auf neue Version 8.8.2.
- Vorbereitung von mehr Konfigurationsmoeglichkeiten in rc.config.
* Thu Jan  2 1997 florian@suse.de
- added two small patches from Eric Allman(?)
* Thu Jan  2 1997 florian@suse.de
- update to newer version
* Thu Jan  2 1997 florian@suse.de
- added security fix
- use "FEATURE(nocanonify)" instead of editing the .cf file
